DATA_DIR = "/usr/share"
LIB_DIR = "/usr/lib"
VERSION = "2.13.91"
PACKAGE = "deskbar-applet"
PYTHONDIR = "/usr/lib/python2.4/site-packages"
